import React from "react";
import Link from "next/link";
import { Button } from "@/app/components/ui/button";
import { HeartIcon, InformationCircleIcon } from "@heroicons/react/24/outline";
import {
  Tooltip,
  TooltipContent,
  TooltipTrigger,
} from "@/app/components/ui/tooltip";

type ActionMenuProps = {
  children?: React.ReactNode;
};

export function ActionMenu({ children }: ActionMenuProps) {
  return (
    <div className="absolute top-0 right-0 flex flex-col items-end mx-3 mt-2">
      <div className="flex items-center bg-secondary rounded-md p-2 gap-2">
        {children}
        <Tooltip>
          <TooltipTrigger asChild>
            <Link href={"https://git.fascinated.cc/Paste"} target="_blank">
              <Button>
                <InformationCircleIcon width={24} height={24} />
              </Button>
            </Link>
          </TooltipTrigger>
          <TooltipContent className="flex flex-col gap-2">
            <div>
              <p className="font-semibold">This project is open source!</p>

              <div className="flex gap-1.5 items-center">
                <p>Made with</p>
                <HeartIcon width={16} height={16} color="#e31b23" />
                <p>by Fascinated</p>
              </div>
            </div>

            <p>Click to view the Source Code</p>
          </TooltipContent>
        </Tooltip>
      </div>
    </div>
  );
}
